package io.renren.modules.admin.entity;

import java.io.Serializable;
import java.util.Date;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonIgnore;

import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;
import io.renren.common.validator.group.AddGroup;
import io.renren.common.validator.group.UpdateGroup;

import lombok.Data;
/**
 * 会员表
 * 
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2020-01-17 11:29:03
 */
@Data
@TableName("member")
public class MemberEntity implements Serializable {
	private static final long serialVersionUID = 1L;

	/**
	 * 会员id (会员表)
	 */
	@TableId
	private Long id;
	/**
	 * 用户名
	 */
	@NotBlank(message="用户名不能为空", groups = AddGroup.class)
	private String username;
	/**
	 * 密码
	 */
	@NotBlank(message="密码不能为空", groups = AddGroup.class)
	// @JsonIgnore
	private String password;
	/**
	 * 盐
	 */
	@JsonIgnore
	private String salt;
	/**
	 * 姓名
	 */
	@NotBlank(message="姓名不能为空", groups = {AddGroup.class, UpdateGroup.class})
	private String truename;
	/**
	 * 性别
	 */
	private Integer sex;
	/**
	 * 头像
	 */
	private String titlePic;
	/**
	 * 所属机构(单位名称、公司名称
	 */
	private String organization;
	/**
	 * 职位id
	 */
	private String position;
	/**
	 * 职称
	 */
	private String jobTitle;
	/**
	 * 电话
	 */
	@NotBlank(message="手机号不能为空", groups = {AddGroup.class, UpdateGroup.class})
	private String phone;
	/**
	 * 邮箱
	 */
	@Email(message="邮箱格式不正确", groups = {AddGroup.class, UpdateGroup.class})
	private String email;
	/**
	 * 办公电话
	 */
	private String officephone;
	/**
	 * 其他联系方式
	 */
	private String otherphone;
	/**
	 * 负责人id
	 */
	private Long servicerId;
	/**
	 * 备注
	 */
	private String note;
	/**
	 * 创建时间
	 */
	private Date createTime;
	/**
	 * 修改时间
	 */
	private Date modifyTime;
	/**
	 * 是否通过审核 0:未通过 1:通过
	 */
	private Integer isCheck;
	/**
	 * 是否被删除 状态  0：正常   1：删除
	 */
	private Integer isDel;
	/**
	 * 修改人
	 */
	private Long modifyId;
	/**
	 * 修改人
	 */
	private Long createId;
}
